sprite = {}

function sprite:new (o)
      o = o or {}   -- create object if user does not provide one
      setmetatable(o, self)
      self.__index = self
      return o
end

function sprite:animate()
    self.counter = self.counter + global.timeValue
	if self.counter > (10/math.abs(global.speed)) then
		self:incrementFrame()
		self.counter = 0
	end
end

function sprite:incrementFrame()
	if self.frame >= self.maxFrame then
		self.frame = 1
	else
		self.frame = self.frame + 1
	end
end

function sprite:moveLeft()
	local newX
	local test
	self.face = 'left'
	self:animate()

	newX = self.x - (global.speed * global.timeValue)
	test = solidCheck(newX, self.y + (self.height/2), self.width, self.height/2)
	if test == false then
		self.x = newX
	end
end

function sprite:moveRight()
	local newX
	local test
	self.face = 'right'
	self:animate()
	
	newX = self.x + (global.speed * global.timeValue)
	
	test = solidCheck(newX, self.y + (self.height/2), self.width, self.height/2)
	if test == false then
		self.x = newX
	end
end

function sprite:moveDown()
	local newY
	local test
	self.face = 'down'
	self:animate()

	newY = self.y + (global.speed * global.timeValue)
	test = solidCheck(self.x, newY + (self.height/2), self.width, self.height/2)
	if test == false then
		self.y = newY
	end
end

function sprite:moveUp()
	
	self.face = 'up'
	self:animate()
	newY = self.y - (global.speed * global.timeValue)
	test = solidCheck(self.x, newY + (self.height/2), self.width, self.height/2)
	if test == false then
		self.y = newY
	end
end

function sprite:draw()
	love.graphics.drawq(self.sheet, self[self.face][self.frame], self.x, self.y)
end

function sprite:initialize(img)
	local sheetWidth = 160
	local sheetHeight = 256
	local spriteWidth = 40
	local spriteHeight = 64
	local down = {}
	local up = {}
	local right = {}
	local left = {}
	local spriteX
	local spriteY
	local theQuad
	if global.spriteHolder[img] == nil then
		for rowLoop = 1, global.spriteRows, 1 do
			for spriteLoop = 1, global.spritesPerRow, 1 do
				spriteX = (spriteLoop - 1) * spriteWidth
				spriteY = spriteHeight * (rowLoop - 1)
				theQuad = love.graphics.newQuad(spriteX, spriteY, spriteWidth, spriteHeight, sheetWidth, sheetHeight)
				if rowLoop == 1 then
					down[spriteLoop] = theQuad
				end
				if rowLoop == 2 then
					left[spriteLoop] = theQuad
				end
				if rowLoop == 3 then
					right[spriteLoop] = theQuad
				end
				if rowLoop == 4 then
					up[spriteLoop] = theQuad
				end
			end
		end
		global.spriteHolder[img] = {}
		global.spriteHolder[img]['down'] = down
		global.spriteHolder[img]['left'] = left
		global.spriteHolder[img]['right'] = right
		global.spriteHolder[img]['up'] = up
	end
	global.spriteHolder[img].sheet = love.graphics.newImage(img)
	global.spriteHolder[img].maxFrame = global.spritesPerRow
	self.down = down
	self.left = left
	self.right = right
	self.up = up
	self.sheet = global.spriteHolder[img].sheet
	self.face = 'down'
	self.counter = 0
	self.frame = 1
	self.x = 0
	self.y = 0
	self.width = spriteWidth
	self.height = spriteHeight
	self.maxFrame = global.spriteHolder[img].maxFrame
	self.onScreen = false
	self.lastDrawCheckX = nil
	self.lastDrawCheckY = nil
end

function sprite:centerX()
	return self.x + (self.width/2)
end

function sprite:centerY()
	return self.y + (self.height/2)
end

function sprite:resetAnimation()
	self.frame = 1
end